| rangen-package | R Documentation |
Provides a collection of random number generators for common and custom distributions, along with utility functions for sampling and simulation.
| Package: | \packageNamerangen |
| Type: | \packageTyperangen |
| Version: | \packageVersionrangen |
| Date: | \packageDaterangen |
| License: | \packageLicenserangen |
Manos Papadakis <papadakm95@gmail.com>
Manos Papadakis <papadakm95@gmail.com>
Michail Tsagris <mtsagris@uoc.gr>
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.